//+------------------------------------------------------------------+
//|                                               sysWickRev 1.0.mq4 |
//|                                                         NickBixy |
//|                           https://www.mql5.com/en/users/nickbixy |
//+------------------------------------------------------------------+
#property copyright "NickBixy"
#property link      "https://www.mql5.com/en/users/nickbixy"
#property version   "1.00"
#property strict
#property indicator_chart_window
#property indicator_buffers 2

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
input double wickM=2.5;//Wick Multiplier (wick larger then body)
input double bodyP=.25;//Body percentage (in the top/bottom percent of candle)
int barsBack=50;


input string info="https://docs.mql4.com/constants/objectconstants/wingdings";//Windings font symbols
input string bearishHeader="-----------------Bearish Arrow Settings------------------------------------------";//----- Bearish Arrow Settings
input color bearishArrowColor=clrOrangeRed;//Bearish Arrow Color
input int bearishWinding=159;//Arrow Wingding Character
input int bearishArrowSize=1;//Bearish Arrow Size 1-5

input string bullishHeader="-----------------Bullish Arrow Settings------------------------------------------";//----- Bullish Arrow Settings
input color bullishArrowColor=clrAqua;//Bullish Arrow Color
input int bullishWinding=159;//Arrow Wingding Character
input int bullishArrowSize=1;//Bullish Arrow Size 1-5


double BEARISH[];
double BULLISH[];


int    nShift;


//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int OnInit()
  {
   IndicatorShortName("sysWickRev");

//Bearish Set up
   SetIndexLabel(0,"sysWickRev Bearish");
   SetIndexStyle(0,DRAW_ARROW,STYLE_SOLID,bearishArrowSize,bearishArrowColor);//sell
   SetIndexArrow(0,bearishWinding);
   SetIndexBuffer(0,BEARISH);

//Bullish Set up
   SetIndexLabel(1,"sysWickRev Bullish");
   SetIndexStyle(1,DRAW_ARROW,STYLE_SOLID,bullishArrowSize,bullishArrowColor);//buy
   SetIndexArrow(1,bullishWinding);
   SetIndexBuffer(1,BULLISH);

   switch(Period())
     {
      case     1:
         nShift = 5;
         break;
      case     5:
         nShift = 7;
         break;
      case    15:
         nShift = 9;
         break;
      case    30:
         nShift = 14;
         break;
      case    60:
         nShift = 19;
         break;
      case   240:
         nShift = 24;
         break;
      case  1440:
         nShift = 84;
         break;
      case 10080:
         nShift = 104;
         break;
      case 43200:
         nShift = 204;
         break;
     }


   ArrayInitialize(BEARISH,0.0);
   ArrayInitialize(BULLISH,0.0);

   return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
  {
   int limit;
   int counted_bars=IndicatorCounted();
//---- check for possible errors
   if(counted_bars<0)
      return(-1);
//---- the last counted bar will be recounted
   if(counted_bars>0)
      counted_bars--;
   limit=Bars-counted_bars;
//---- main loop
   for(int i=0; i<limit; i++)
     {

      double openPrice= iOpen(_Symbol,PERIOD_CURRENT,i);
      double closePrice= iClose(_Symbol,PERIOD_CURRENT,i);
      double highPrice= iHigh(_Symbol,PERIOD_CURRENT,i);
      double lowPrice= iLow(_Symbol,PERIOD_CURRENT,i);

      double candleSizeTotal=0;
      for(int j=1; j<=barsBack; j++)
        {
         candleSizeTotal+=iHigh(_Symbol,PERIOD_CURRENT,i+j)-iLow(_Symbol,PERIOD_CURRENT,i+j);
        }
      double averageCandleSize=candleSizeTotal/barsBack;


      if(((closePrice > openPrice) && (openPrice - lowPrice) >= ((closePrice - openPrice)* wickM) && (highPrice - closePrice) <= ((highPrice - lowPrice) * bodyP))
         ||
         ((closePrice < openPrice) && (closePrice - lowPrice) >= ((openPrice - closePrice) * wickM) && (highPrice - closePrice) <= ((highPrice - lowPrice) * bodyP))
         ||
         ((closePrice == openPrice && closePrice != highPrice) && (highPrice - lowPrice) >= ((highPrice - closePrice) * wickM) && (highPrice - closePrice) <= ((highPrice - lowPrice) * bodyP))
         ||
         ((openPrice==highPrice)&& (closePrice==highPrice) && ((highPrice-lowPrice)>=averageCandleSize)))
        {
         BULLISH[i]=Low[i]-nShift*Point;
         BEARISH[i]=0.0;
        }
      else
         if(((closePrice < openPrice) && (highPrice - openPrice) >= ((openPrice - closePrice)* wickM) && (closePrice - lowPrice) <= ((highPrice - lowPrice) * bodyP))
            ||
            ((closePrice > openPrice) && (highPrice - closePrice) >= ((closePrice - openPrice) * wickM) && (closePrice - lowPrice) <= ((highPrice - lowPrice) * bodyP))
            ||
            ((closePrice == openPrice && closePrice != lowPrice) && (highPrice - lowPrice) >= ((closePrice - lowPrice) * wickM) &&(closePrice - lowPrice) <= ((highPrice - lowPrice) * bodyP))
            ||
            ((openPrice==lowPrice)&& (closePrice==lowPrice) && ((highPrice-lowPrice)>=averageCandleSize)))
           {
            BEARISH[i]=High[i]+nShift*Point;
            BULLISH[i]=0.0;
           }
         else
           {
            BEARISH[i]=0.0;
            BULLISH[i]=0.0;
           }
     }

   return(0);
  }
//+------------------------------------------------------------------+
